[Bf-blender-cvs] [23e365f5596] greasepencil-object: Do no render edit points

Antonio Vazquez noreply at git.blender.org
Sun Jan 21 16:41:34 CET 2018


Commit: 23e365f5596030df5fb45747f1fa919ad3068428
Author: Antonio Vazquez
Date:   Sun Jan 21 16:38:51 2018 +0100
Branches: greasepencil-object
https://developer.blender.org/rB23e365f5596030df5fb45747f1fa919ad3068428

Do no render edit points

The edit points are only visible in viewport but are disabled when make a render.

===================================================================

M	source/blender/draw/engines/gpencil/gpencil_draw_cache_impl.c

===================================================================

diff --git a/source/blender/draw/engines/gpencil/gpencil_draw_cache_impl.c b/source/blender/draw/engines/gpencil/gpencil_draw_cache_impl.c
index 33a7ddcf2b5..96e34a9b7e7 100644
--- a/source/blender/draw/engines/gpencil/gpencil_draw_cache_impl.c
+++ b/source/blender/draw/engines/gpencil/gpencil_draw_cache_impl.c
@@ -690,6 +690,7 @@ static void gpencil_draw_strokes(GpencilBatchCache *cache, GPENCIL_e_data *e_dat
 	float viewmatrix[4][4];
 	bool is_multiedit = (bool)GPENCIL_MULTIEDIT_SESSIONS_ON(gpd);
 	bool playing = (bool)stl->storage->playing;
+	bool is_render = (bool)stl->storage->is_render;
 
 	/* Get evaluation context */
 	/* NOTE: We must check if C is valid, otherwise we get crashes when trying to save files
@@ -798,8 +799,8 @@ static void gpencil_draw_strokes(GpencilBatchCache *cache, GPENCIL_e_data *e_dat
 			}
 		}
 
-		/* edit points (only in edit mode and not play animation) */
-		if ((src_gps) && (!playing)) {
+		/* edit points (only in edit mode and not play animation not render) */
+		if ((src_gps) && (!playing) && (!is_render)) {
 			if (!stl->g_data->shgrps_edit_line) {
 				stl->g_data->shgrps_edit_line = DRW_shgroup_create(e_data->gpencil_line_sh, psl->edit_pass);
 				stl->g_data->tot_sh++;



More information about the Bf-blender-cvs mailing list